@@ -54,11 +54,15 @@ public:
   virtual void load_from_document(); //View override
 
   typedef std::vector< Field > type_vecFields;
+
+  static type_vecFields get_fields_for_table_from_database(const Glib::ustring& table_name);
     
 protected:
   typedef std::vector<Glib::ustring> type_vecStrings;
   type_vecStrings get_table_names();
 
+  type_vecFields get_fields_for_table(const Glib::ustring& table_name) const;
+
   virtual void fill_from_database();
   virtual void fill_end(); //Call this from the end of fill_from_database() overrides.
 
@@ -66,9 +70,11 @@ protected:
 
   Glib::ustring util_string_from_decimal(guint decimal);
   guint util_decimal_from_string(const Glib::ustring& str);
+
+  static type_vecStrings util_vecStrings_from_Fields(const type_vecFields& fields);
   
   virtual void handle_error(const std::exception& ex); //TODO_port: This is probably useless now.
-  virtual void handle_error();
+  virtual bool handle_error();
 
   virtual Glib::RefPtr<Gnome::Gda::DataModel> Query_execute(const Glib::ustring& strQuery);
 
