@@ -84,14 +84,51 @@ void Document_Glom::set_connection_database(const Glib::ustring& strVal)
 }
 
 
-Document_Glom::type_vecRelationships Document_Glom::get_relationships(const Glib::ustring& strTableName)
+bool Document_Glom::get_relationship(const Glib::ustring& table_name, const Glib::ustring& relationship_name, Relationship& relationship) const
+{
+  //Initialize output parameter:
+  relationship = Relationship();
+
+  const xmlpp::Element* nodeTable = get_node_table(table_name);
+  if(nodeTable)
+  {
+    const xmlpp::Element* nodeRelationships = get_node_child_named(nodeTable, "relationships");
+    if(nodeRelationships)
+    {
+      const xmlpp::Node::NodeList listNodes = nodeRelationships->get_children("relationship");
+      for(xmlpp::Node::NodeList::const_iterator iter = listNodes.begin(); iter != listNodes.end(); iter++)
+      {
+        const xmlpp::Element* nodeChild = dynamic_cast<xmlpp::Element*>(*iter);
+        if(nodeChild)
+        {
+          const Glib::ustring this_relationship_name = get_node_attribute_value(nodeChild, "name");
+          if(this_relationship_name == relationship_name)
+          {
+            relationship.set_from_table( table_name );
+            relationship.set_name( relationship_name );
+            relationship.set_from_field( get_node_attribute_value(nodeChild, "key") );
+            relationship.set_to_table( get_node_attribute_value(nodeChild, "other_table") );
+            relationship.set_to_field( get_node_attribute_value(nodeChild, "other_key") );
+
+            return true; //success.
+          }
+        }
+      }
+    }
+  }
+            
+  return false; //failed.
+}
+
+  
+Document_Glom::type_vecRelationships Document_Glom::get_relationships(const Glib::ustring& strTableName) const
 {
   type_vecRelationships vecResult;
 
-  xmlpp::Element* nodeTable = get_node_table(strTableName);
+  const xmlpp::Element* nodeTable = get_node_table(strTableName);
   if(nodeTable)
   {
-    xmlpp::Element* nodeRelationships = get_node_child_named_with_add(nodeTable, "relationships");
+    const xmlpp::Element* nodeRelationships = get_node_child_named(nodeTable, "relationships");
     if(nodeRelationships)
     {
       xmlpp::Node::NodeList listNodes = nodeRelationships->get_children();
@@ -875,6 +912,27 @@ void Document_Glom::emit_userlevel_changed()
   m_signal_userlevel_changed.emit(m_app_state.get_userlevel());
 }
 
+Glib::ustring Document_Glom::get_default_table() const
+{
+  const xmlpp::Element* nodeRoot = get_node_document();
+  if(nodeRoot)
+  {
+    //Look at each "table" node.
+    xmlpp::Node::NodeList listNodes = nodeRoot->get_children("table");
+    for(xmlpp::Node::NodeList::const_iterator iter = listNodes.begin(); iter != listNodes.end(); iter++)
+    {
+      const xmlpp::Element* nodeChild = dynamic_cast<const xmlpp::Element*>(*iter);
+      if(nodeChild)
+      {
+        if(get_node_attribute_value_as_bool(nodeChild, "default"))
+          return get_node_attribute_value(nodeChild, "name");
+      }
+    }
+  }
+  
+  return ""; //There is no default table.
+}
+
  
 
   
